"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var Styling_1 = require("../../Styling");
var Utilities_1 = require("../../Utilities");
var noOutline = {
    outline: 0
};
/**
 * Gets the base button styles. Note: because it is a base class to be used with the `mergeRules`
 * helper, it should have values for all class names in the interface. This let `mergeRules` optimize
 * mixing class names together.
 */
exports.getStyles = Utilities_1.memoize(function (theme, focusInset, focusColor) {
    var iconStyle = Styling_1.mergeStyles({
        margin: '0 4px',
        height: '16px',
        lineHeight: '16px',
        textAlign: 'center',
        verticalAlign: 'middle'
    });
    return {
        root: Styling_1.mergeStyles(Styling_1.getFocusStyle(theme, focusInset, focusColor), theme.fonts.medium, {
            // this transparent border converts to the correct colors in HC mode
            boxSizing: 'border-box',
            border: '1px solid transparent',
            userSelect: 'none',
            display: 'inline-block',
            textDecoration: 'none',
            textAlign: 'center',
            cursor: 'pointer',
            verticalAlign: 'top',
            padding: '0 16px'
        }),
        rootEnabled: undefined,
        rootDisabled: Styling_1.mergeStyles({
            backgroundColor: theme.palette.neutralLighter,
            color: theme.palette.neutralTertiary,
            cursor: 'default',
            pointerEvents: 'none',
            ':hover': noOutline,
            ':focus': noOutline
        }),
        flexContainer: Styling_1.mergeStyles({
            display: 'flex',
            height: '100%',
            flexWrap: 'nowrap',
            justifyContent: 'center',
            alignItems: 'center'
        }),
        icon: Styling_1.mergeStyles(iconStyle, {
            fontSize: Styling_1.FontSizes.icon
        }),
        iconEnabled: undefined,
        iconDisabled: undefined,
        menuIcon: Styling_1.mergeStyles(iconStyle, {
            fontSize: Styling_1.FontSizes.small,
        }),
        menuIconEnabled: undefined,
        menuIconDisabled: undefined,
        label: Styling_1.mergeStyles({
            margin: '0 4px',
            lineHeight: '100%'
        }),
        labelEnabled: undefined,
        labelDisabled: undefined,
        description: undefined,
        descriptionEnabled: undefined,
        descriptionDisabled: undefined,
        screenReaderText: Styling_1.mergeStyles({
            position: 'absolute',
            width: '1px',
            height: '1px',
            margin: '-1px',
            padding: 0,
            overflow: 'hidden',
            clip: 'rect(0,0,0,0)',
            border: 0
        })
    };
});

//# sourceMappingURL=BaseButton.styles.js.map
